.. :changelog:

Release history
---------------

0.3.0 (2016-10-28)
++++++++++++++++++

**Features**

- ``gstorage.bucket.Bucket.get_default`` allowing easy access to
  default bucket.
- ``gstorage.bucket.Bucket.copydir`` allowing easy upload of files
  to Google cloud.
